@@ -181,7 +181,7 @@ class Tag(Dict):
     """A tag represents the metadata for a label that is applies as a feature on a content node"""
 
     def __init__(self, start: Optional[int] = None, end: Optional[int] = None, value: Optional[str] = None,
-                 uuid: Optional[str] = None, data: Any = None, *args,
+                 uuid: Optional[str] = None, data: Any = None, *args, confidence: Optional[float] = None,
                  **kwargs):
         super().__init__(*args, **kwargs)
         self.start: Optional[int] = start
@@ -194,6 +194,8 @@ class Tag(Dict):
         """Any data object (JSON serializable) that you wish to associate with the label"""
         self.uuid: Optional[str] = uuid
         """The UUID for this tag instance, this allows tags that are on different content nodes to be related through the same UUID"""
+        self.confidence: Optional[float] = confidence
+        """The confidence of the tag in a range of 0-1"""
 
 
 class FindDirection(Enum):
@@ -1592,12 +1594,17 @@ class Document(object):
     def __str__(self):
         return f"kodexa://{self.uuid}"
 
-    def __init__(self, metadata=None, content_node: ContentNode = None, source=None):
+    def __init__(self, metadata=None, content_node: ContentNode = None, source=None, ref: str = None):
         if metadata is None:
             metadata = DocumentMetadata()
         if source is None:
             source = SourceMetadata()
 
+        # The ref is not stored and is used when we have
+        # initialized a document from a remote store and want
+        # to keep track of that
+        self.ref = ref
+
         self.metadata: DocumentMetadata = metadata
         self.content_node: Optional[ContentNode] = content_node
         self.virtual: bool = False
@@ -1996,6 +2003,13 @@ class TransitionType(Enum):
     """A transition that placed a fragment of the document in another document"""
 
 
+class BaseEvent:
+    """
+    The base for all events within Kodexa
+    """
+    pass
+
+
 class ContentEventType(Enum):
     """
     The type of event that occurred on the content
@@ -2004,11 +2018,13 @@ class ContentEventType(Enum):
     DERIVED_DOCUMENT = 'DERIVED_DOCUMENT'
 
 
-class ContentEvent:
+class ContentEvent(BaseEvent):
     """A content event represents a change, update or deletion that has occurred in a document family
     in a store, and can be relayed for a reaction
     """
 
+    type = "content"
+
     def __init__(self, content_object: ContentObject, event_type: ContentEventType, document_family):
         """
         Initialize a content event
@@ -2034,7 +2050,48 @@ class ContentEvent:
         return {
             'contentObject': self.content_object.to_dict(),
             'documentFamily': self.document_family.to_dict(),
-            'eventType': self.event_type
+            'eventType': self.event_type,
+            'type': self.type
+        }
+
+
+class AssistantEventType(Enum):
+    """
+    The type of event that is being provided to the assistant
+    """
+    PROCESS_DOCUMENT = 'PROCESS_DOCUMENT'
+
+
+class AssistantEvent(BaseEvent):
+    type = "assistant"
+
+    """
+    A assistant event represents an interaction, usually from a user or an API, to evalute
+    and respond to a document
+    """
+
+    def __init__(self, content_object: ContentObject, event_type: AssistantEventType):
+        """
+        Initialize a content event
+        Args:
+            content_object: the content object on which the event occurred
+            event_type: the type of event
+        """
+        self.content_object = content_object
+        """The assistant event"""
+        self.event_type = event_type
+        """The event type"""
+
+    @classmethod
+    def from_dict(cls, event_dict: dict):
+        return AssistantEvent(ContentObject.from_dict(event_dict['contentObject']),
+                              AssistantEventType[event_dict['eventType']])
+
+    def to_dict(self):
+        return {
+            'contentObject': self.content_object.to_dict(),
+            'eventType': self.event_type,
+            'type': self.type
         }
 
 
@@ -2065,7 +2122,7 @@ class DocumentTransition:
 
     def __init__(self, transition_type: TransitionType, source_content_object_id: str,
                  destination_content_object_id: Optional[str] = None,
-                 actor: Optional[DocumentActor] = None):
+                 actor: Optional[DocumentActor] = None, execution_id: Optional[str] = None):
         """
         Create a document transition
 
@@ -2073,7 +2130,8 @@ class DocumentTransition:
             transition_type:TransitionType: the type of transition
             source_content_object_id:str: the ID of the source content object
             destination_content_object_id:Optional[str] the ID of the destination content object
-            actor:Optional[DocumentActor]: the actor (Defaults to None)
+            actor (Optional[DocumentActor]): the actor (Defaults to None)
+            execution_id (Optional[str]): the ID of the execution that created this transition
         """
         self.transition_type = transition_type
         """The type of transition"""
@@ -2083,9 +2141,11 @@ class DocumentTransition:
         """The ID of the destination content object"""
         self.actor = actor
         """The actor in the transition"""
+        self.execution_id = execution_id
+        """The ID of the execution that created this transition"""
 
     @classmethod
-    def from_dict(cls, transition_dict):
+    def from_dict(cls, transition_dict: dict):
         """
         Converts a dictionary from a REST call back into a DocumentTransition
         Args:
@@ -2095,7 +2155,8 @@ class DocumentTransition:
 
         """
         transition = DocumentTransition(transition_dict['transitionType'], transition_dict['sourceContentObjectId'],
-                                        transition_dict['destinationContentObjectId'])
+                                        transition_dict['destinationContentObjectId'],
+                                        execution_id=transition_dict.get('executionId'))
         return transition
 
     def to_dict(self) -> dict:
@@ -2108,7 +2169,8 @@ class DocumentTransition:
         return {
             'transitionType': self.transition_type,
             'sourceContentObjectId': self.source_content_object_id,
-            'destinationContentObjectId': self.destination_content_object_id
+            'destinationContentObjectId': self.destination_content_object_id,
+            'executionId': self.execution_id
         }
 
 
@@ -2126,14 +2188,20 @@ class DocumentFamily:
         Creates a new document family at the given path and optionally with the
         document as its first entry
 
-        :param path: the path at which this document family exists (i.e. my-file.pdf)
-        :param store_ref: the reference to the store holding this family
+        Args:
+            path (str): the path at which this document family exists (i.e. my-file.pdf)
+            store_ref (str): the reference to the store holding this family
         """
         self.id: str = str(uuid.uuid4())
+        """The ID of this document family"""
         self.transitions: List[DocumentTransition] = []
+        """A list of the transitions within the document family"""
         self.content_objects: List[ContentObject] = []
+        """A list of the content objects in the document family"""
         self.path = path
+        """The path for this document family in the store (akin to a filename)"""
         self.store_ref = store_ref
+        """The reference to the store containing the document family"""
 
     def add_document(self, document: Document, transition: Optional[DocumentTransition] = None) -> ContentEvent:
         """
@@ -2224,6 +2292,11 @@ class DocumentFamily:
 
 
 class DocumentStore:
+
+    def __init__(self, store_type='DOCUMENT', store_purpose='OPERATIONAL'):
+        self.store_type = store_type
+        self.store_purpose = store_purpose
+
     """
     A document store supports storing, listing and retrieving Kodexa documents and document families
     """
@@ -2465,7 +2538,12 @@ class DocumentStore:
 
         """
         last_co = document_family.content_objects[-1]
-        return self.get_document_by_content_object(document_family, last_co)
+        document = self.get_document_by_content_object(document_family, last_co)
+
+        if document is not None:
+            document.ref = f"{self.get_ref()}/{document_family.id}/{last_co.id}"
+
+        return document
 
 
 class ModelStore:
