@@ -9,7 +9,7 @@ from kodexa import Assistant, AssistantResponse, LocalDocumentStore
 from kodexa import ContentEvent, ContentNode, Document, DocumentActor, DocumentTransition, PipelineContext, \
     TableDataStore, TransitionType
 from kodexa.assistant.assistant import AssistantMetadata
-from kodexa.model.model import DocumentStore
+from kodexa.model.model import AssistantEvent, ContentObjectReference, DocumentStore
 
 logger = logging.getLogger('kodexa.testing')
 
@@ -239,6 +239,9 @@ class AssistantTestHarness:
         for store in self.stores:
             store.register_listener(self)
 
+    def test_assistant_event(self, assistant_event: AssistantEvent):
+        pass
+
     def process_event(self, event: ContentEvent):
         """The harness will take the content event and
         will pass it to the assistant - then we will
@@ -253,7 +256,7 @@ class AssistantTestHarness:
 
         """
         from kodexa import AssistantContext
-        assistant_context = AssistantContext(self.metadata, self.kodexa_metadata_path)
+        assistant_context = AssistantContext(self.metadata, self.kodexa_metadata_path, self.stores)
 
         response: AssistantResponse = self.assistant.process_event(event, assistant_context)
 
@@ -264,10 +267,12 @@ class AssistantTestHarness:
             document = store.get_document_by_content_object(event.document_family, event.content_object)
             if document is not None:
                 pipeline = assistant_pipeline.pipeline
-                pipeline.connector = [document]
+                pipeline.connector = [
+                    ContentObjectReference(content_object=event.content_object, document=document, store=store,
+                                           document_family=event.document_family)]
                 pipeline_context = pipeline.run()
 
-                if pipeline_context.output_document is not None:
+                if pipeline_context.output_document is not None and assistant_pipeline.write_back_to_store:
                     # We need to build the transition between the old and the new
                     document_relationship = DocumentTransition(TransitionType.DERIVED, event.content_object.id, None,
                                                                DocumentActor("testing", "assistant"))
@@ -275,12 +280,6 @@ class AssistantTestHarness:
                     store.add_related_document_to_family(event.document_family.id, document_relationship,
                                                          pipeline_context.output_document)
 
-                # We need to handle the context here, basically we are going to take the result
-                # of the pipeline as a new document and add it to the family?? think about that?
-
-                # so does the assistant decide to write to the store? or do we just do it anyway?
-                # how does the assistant know what happened to the pipeline?
-
         pass
 
     def register_local_document_store(self, store: LocalDocumentStore):
@@ -389,11 +388,26 @@ class ExtensionPackUtil:
                 # We need to create and return our action
                 module = importlib.import_module(service.step.package)
                 klass = getattr(module, service.step['class'])
-                return klass(**options)
+                new_instance = klass(**options)
+
+                # Since we will be using to access metadata we will need to
+                # make sure we have a to_dict() that is able to convert this step properly
+
+                import types
+
+                def general_to_dict(self):
+                    return {
+                        'ref': f'./{action_slug}',
+                        'options': options
+                    }
+
+                new_instance.to_dict = types.MethodType(general_to_dict, new_instance)
+                return new_instance
 
         raise Exception("Unable to find the action " + action_slug)
 
-    def get_assistant_test_harness(self, assistant_slug, assistant_metadata: AssistantMetadata, options=None, stores=None) -> AssistantTestHarness:
+    def get_assistant_test_harness(self, assistant_slug, assistant_metadata: AssistantMetadata, options=None,
+                                   stores=None) -> AssistantTestHarness:
         """Provides a local test harness that can be used to validate the functionality
         of an assistant in a test case
 
